unwrap_key_raw

Function unwrap_key_raw 

pub async fn unwrap_key_raw(
    variant: AesVariant,
    input: UnwrapInput,
    options: AeadKeyOptions,
) -> Result<Aead, Error>
Mint an AES-GCM key of the declared variant from unwrapped key material read as raw bytes, subject to import_key_raw’s contract. Consumes the UnwrapInput.