pub async fn unwrap_key_jwk(
variant: AesVariant,
input: UnwrapInput,
options: KwKeyOptions,
) -> Result<KwKey, Error>Expand description
Mint an AES-KW key from unwrapped key material read as an oct JWK.
Consumes the UnwrapInput.
pub async fn unwrap_key_jwk(
variant: AesVariant,
input: UnwrapInput,
options: KwKeyOptions,
) -> Result<KwKey, Error>Mint an AES-KW key from unwrapped key material read as an oct JWK.
Consumes the UnwrapInput.