pub async fn unwrap_key_raw(
variant: AesVariant,
input: UnwrapInput,
options: KwKeyOptions,
) -> Result<KwKey, Error>Expand description
Mint an AES-KW key from unwrapped key material read as raw bytes.
Consumes the UnwrapInput.
pub async fn unwrap_key_raw(
variant: AesVariant,
input: UnwrapInput,
options: KwKeyOptions,
) -> Result<KwKey, Error>Mint an AES-KW key from unwrapped key material read as raw bytes.
Consumes the UnwrapInput.