generate_key

Function generate_key 

pub async fn generate_key(
    variant: AesVariant,
    options: KwKeyOptions,
) -> Result<KwKey, Error>
Generate a fresh random key of the given AES variant. Fails with error.unsupported if this implementation does not serve the variant.