pub async fn generate_key(
variant: EcdhVariant,
options: AgreementKeyOptions,
) -> Result<(SecretKey, PublicKey), Error>Expand description
Generate a fresh key pair on the declared variant’s curve.
pub async fn generate_key(
variant: EcdhVariant,
options: AgreementKeyOptions,
) -> Result<(SecretKey, PublicKey), Error>Generate a fresh key pair on the declared variant’s curve.