pub async fn unwrap_key_jwk(
input: UnwrapInput,
options: MacKeyOptions,
) -> Result<MacKey, Error>Expand description
Mint a key from unwrapped key material read as an RFC 7517 JSON
Web Key. See hmac-sha2.unwrap-key-jwk.
pub async fn unwrap_key_jwk(
input: UnwrapInput,
options: MacKeyOptions,
) -> Result<MacKey, Error>Mint a key from unwrapped key material read as an RFC 7517 JSON
Web Key. See hmac-sha2.unwrap-key-jwk.