pub async fn unwrap_key_raw(
input: UnwrapInput,
options: MacKeyOptions,
) -> Result<MacKey, Error>Expand description
Mint a key from unwrapped key material read as raw bytes. See
hmac-sha2.unwrap-key-raw.
pub async fn unwrap_key_raw(
input: UnwrapInput,
options: MacKeyOptions,
) -> Result<MacKey, Error>Mint a key from unwrapped key material read as raw bytes. See
hmac-sha2.unwrap-key-raw.