import_signing_key_jwk

Function import_signing_key_jwk 

pub async fn import_signing_key_jwk(
    variant: EcdsaVariant,
    jwk: impl Into<String>,
    options: SigningKeyOptions,
) -> Result<SigningKey, Error>
Import a signing key as an EC private JWK (kty: "EC", with crv, d, and the mandatory public coordinates x/y; as JSON text). crv and alg are validated as in import_verifying_key_jwk.

Security: implementations MAY validate x/y against d, and never trust them for any operation.