pub async fn unwrap_password(
input: UnwrapInput,
options: DeriveOptions,
) -> Result<Password, Error>Expand description
Mint a password from unwrapped bytes, subject to import_password’s
contract. Consumes the UnwrapInput.
pub async fn unwrap_password(
input: UnwrapInput,
options: DeriveOptions,
) -> Result<Password, Error>Mint a password from unwrapped bytes, subject to import_password’s
contract. Consumes the UnwrapInput.