pub fn new<T: StreamPayload>() -> (StreamWriter<T>, StreamReader<T>)Expand description
Creates a new Component Model stream with the specified payload type.
pub fn new<T: StreamPayload>() -> (StreamWriter<T>, StreamReader<T>)Creates a new Component Model stream with the specified payload type.